
{*******************************************************}
{                                                       }
{       RichView                                        }
{       Demo: using RVReportHelper to draw header       }
{                                                       }
{       Copyright (c) Sergey Tkachenko                  }
{       svt@trichview.com                               }
{       http://www.trichview.com                        }
{                                                       }
{*******************************************************}

{
  Header can be printed automatically, if you assing it using RVPrint.SetHeader
  method. But you cannot use SetHeader if you want to use different headers
  for different pages.
  This demo shows how to use RVReportHelper component for drawing header.
  This demo draws the same header for all pages (and displays only the first
  page, but this method can be used to create different headers.
}

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, Menus, RVStyle, RVScroll, RichView, RVEdit, RVReport, PtblRV;

type
  TForm1 = class(TForm)
    rveHeader: TRichViewEdit;
    rveMain: TRichViewEdit;
    RVStyle1: TRVStyle;
    MainMenu1: TMainMenu;
    Demo1: TMenuItem;
    Preview1: TMenuItem;
    RVPrint1: TRVPrint;
    rvhHeader: TRVReportHelper;
    procedure FormCreate(Sender: TObject);
    procedure Preview1Click(Sender: TObject);
    procedure RVPrint1PagePrepaint(Sender: TRVPrint; PageNo: Integer;
      Canvas: TCanvas; Preview: Boolean; PageRect, PrintAreaRect: TRect);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses Unit2;

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
begin
  rveHeader.Clear;
  rveHeader.AddNL('(((', 0, 1);
  rveHeader.Add('Header', 1);
  rveHeader.Add(')))', 0);
  rveHeader.Format;

  rveMain.Clear;
  rveMain.AddNL('Paste here', 0, 0);
  rveMain.Format;

  rvhHeader.RichView.Style := RVStyle1;
  rvhHeader.RichView.RVFOptions :=
    rvhHeader.RichView.RVFOptions+[rvfoLoadBack,rvfoLoadLayout];

  ActiveControl := rveMain;
end;
{------------------------------------------------------------------------------}
procedure TForm1.Preview1Click(Sender: TObject);
  {............................................}
  procedure CopyDoc(src, dst: TCustomRichView);
  var Stream: TMemoryStream;
  begin
    Stream := TMemoryStream.Create;
    src.SaveRVFToStream(Stream, False);
    Stream.Position := 0;
    dst.LoadRVFFromStream(Stream);
    Stream.Free;
  end;
  {............................................}
begin
  CopyDoc(rveHeader, rvhHeader.RichView);
  rvhHeader.RichView.AddNL('', 0, 0); // one line spacing after header
  RVPrint1.AssignSource(rveMain);
  RVPrint1.FormatPages(rvdoAll);
  Form2.RVPrintPreview1.UpdateView;
  Form2.ShowModal;
end;
{------------------------------------------------------------------------------}
procedure TForm1.RVPrint1PagePrepaint(Sender: TRVPrint; PageNo: Integer;
  Canvas: TCanvas; Preview: Boolean; PageRect, PrintAreaRect: TRect);
var pt: TPoint;
begin
  {
    You can insert code generating a header for the PageNo-th page in
    rvhHeader.RichView here.
  }
  rvhHeader.Init(Canvas, PrintAreaRect.Right-PrintAreaRect.Left);
  rvhHeader.FormatNextPage(PrintAreaRect.Bottom-PrintAreaRect.Top);
  with PrintAreaRect do
    SetWindowOrgEx(Canvas.Handle,
      -PrintAreaRect.Left, -(PrintAreaRect.Top-rvhHeader.GetLastPageHeight), @pt);
  rvhHeader.DrawPage(1, Canvas, False, rvhHeader.GetLastPageHeight);
  SetWindowOrgEx(Canvas.Handle, pt.X, pt.Y, nil);
end;

end.
